package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBrewery;

/**
 * 品牌方Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface WyBreweryMapper 
{
    /**
     * 查询品牌方
     * 
     * @param id 品牌方主键
     * @return 品牌方
     */
    public WyBrewery selectWyBreweryById(Long id);
    public Integer selectBreweryCount();

    /**
     * 查询品牌方列表
     * 
     * @param wyBrewery 品牌方
     * @return 品牌方集合
     */
    public List<WyBrewery> selectWyBreweryList(WyBrewery wyBrewery);

    /**
     * 新增品牌方
     * 
     * @param wyBrewery 品牌方
     * @return 结果
     */
    public int insertWyBrewery(WyBrewery wyBrewery);

    /**
     * 修改品牌方
     * 
     * @param wyBrewery 品牌方
     * @return 结果
     */
    public int updateWyBrewery(WyBrewery wyBrewery);

    /**
     * 删除品牌方
     * 
     * @param id 品牌方主键
     * @return 结果
     */
    public int deleteWyBreweryById(Long id);

    /**
     * 批量删除品牌方
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryByIds(Long[] ids);
}
